==> asn1tools-0.139.0.tar.gz: asn1tools-0.139.0/tests/files/ietf/rfc3447.py <==
EXPECTED = {'PKCS-1': {'extensibility-implied': False,
            'imports': {'NIST-SHA2': ['id-sha256', 'id-sha384', 'id-sha512']},
            'object-classes': {'ALGORITHM-IDENTIFIER': {'members': [{'name': '&id',
                                                                     'type': 'OBJECT '
                                                                             'IDENTIFIER'},
                                                                    {'name': '&Type',
                                                                     'type': 'OpenType'}]}},
            'object-sets': {'OAEP-PSSDigestAlgorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                         'members': []},
                            'PKCS1-v1-5DigestAlgorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                           'members': []},
                            'PKCS1Algorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                'members': []},
                            'PKCS1MGFAlgorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                   'members': []},
                            'PKCS1PSourceAlgorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                       'members': []}},
            'tags': 'EXPLICIT',
            'types': {'AlgorithmIdentifier': {'members': [{'name': 'algorithm',
                                                           'table': {'type': 'InfoObjectSet'},
                                                           'type': 'ALGORITHM-IDENTIFIER.&id'},
                                                          {'name': 'parameters',
                                                           'optional': True,
                                                           'table': ['InfoObjectSet',
                                                                     ['.algorithm']],
                                                           'type': 'ALGORITHM-IDENTIFIER.&Type'}],
                                              'type': 'SEQUENCE'},
                      'DigestAlgorithm': {'type': 'AlgorithmIdentifier'},
                      'DigestInfo': {'members': [{'name': 'digestAlgorithm',
                                                  'type': 'DigestAlgorithm'},
                                                 {'name': 'digest',
                                                  'type': 'OCTET STRING'}],
                                     'type': 'SEQUENCE'},
                      'EncodingParameters': {'size': [(0, 'MAX')],
                                             'type': 'OCTET STRING'},
                      'HashAlgorithm': {'type': 'AlgorithmIdentifier'},
                      'MaskGenAlgorithm': {'type': 'AlgorithmIdentifier'},
                      'OtherPrimeInfo': {'members': [{'name': 'prime',
                                                      'type': 'INTEGER'},
                                                     {'name': 'exponent',
                                                      'type': 'INTEGER'},
                                                     {'name': 'coefficient',
                                                      'type': 'INTEGER'}],
                                         'type': 'SEQUENCE'},
                      'OtherPrimeInfos': {'element': {'type': 'OtherPrimeInfo'},
                                          'size': [(1, 'MAX')],
                                          'type': 'SEQUENCE OF'},
                      'PSourceAlgorithm': {'type': 'AlgorithmIdentifier'},
                      'RSAES-AlgorithmIdentifier': {'type': 'AlgorithmIdentifier'},
                      'RSAES-OAEP-params': {'members': [{'default': 'sha1',
                                                         'name': 'hashAlgorithm',
                                                         'tag': {'number': 0},
                                                         'type': 'HashAlgorithm'},
                                                        {'default': 'mgf1SHA1',
                                                         'name': 'maskGenAlgorithm',
                                                         'tag': {'number': 1},
                                                         'type': 'MaskGenAlgorithm'},
                                                        {'default': 'pSpecifiedEmpty',
                                                         'name': 'pSourceAlgorithm',
                                                         'tag': {'number': 2},
                                                         'type': 'PSourceAlgorithm'}],
                                            'type': 'SEQUENCE'},
                      'RSAPrivateKey': {'members': [{'name': 'version',
                                                     'type': 'Version'},
                                                    {'name': 'modulus',
                                                     'type': 'INTEGER'},
                                                    {'name': 'publicExponent',
                                                     'type': 'INTEGER'},
                                                    {'name': 'privateExponent',
                                                     'type': 'INTEGER'},
                                                    {'name': 'prime1',
                                                     'type': 'INTEGER'},
                                                    {'name': 'prime2',
                                                     'type': 'INTEGER'},
                                                    {'name': 'exponent1',
                                                     'type': 'INTEGER'},
                                                    {'name': 'exponent2',
                                                     'type': 'INTEGER'},
                                                    {'name': 'coefficient',
                                                     'type': 'INTEGER'},
                                                    {'name': 'otherPrimeInfos',
                                                     'optional': True,
                                                     'type': 'OtherPrimeInfos'}],
                                        'type': 'SEQUENCE'},
                      'RSAPublicKey': {'members': [{'name': 'modulus',
                                                    'type': 'INTEGER'},
                                                   {'name': 'publicExponent',
                                                    'type': 'INTEGER'}],
                                       'type': 'SEQUENCE'},
                      'RSASSA-AlgorithmIdentifier': {'type': 'AlgorithmIdentifier'},
                      'RSASSA-PSS-params': {'members': [{'default': 'sha1',
                                                         'name': 'hashAlgorithm',
                                                         'tag': {'number': 0},
                                                         'type': 'HashAlgorithm'},
                                                        {'default': 'mgf1SHA1',
                                                         'name': 'maskGenAlgorithm',
                                                         'tag': {'number': 1},
                                                         'type': 'MaskGenAlgorithm'},
                                                        {'default': 20,
                                                         'name': 'saltLength',
                                                         'tag': {'number': 2},
                                                         'type': 'INTEGER'},
                                                        {'default': 'trailerFieldBC',
                                                         'name': 'trailerField',
                                                         'tag': {'number': 3},
                                                         'type': 'TrailerField'}],
                                            'type': 'SEQUENCE'},
                      'SHA1Parameters': {'type': 'NULL'},
                      'TrailerField': {'named-numbers': {'trailerFieldBC': 1},
                                       'type': 'INTEGER'},
                      'Version': {'named-numbers': {'multi': 1, 'two-prime': 0},
                                  'type': 'INTEGER'}},
            'values': {'emptyString': {'type': 'EncodingParameters',
                                       'value': '0x'},
                       'id-RSAES-OAEP': {'type': 'OBJECT IDENTIFIER',
                                         'value': ['pkcs-1', 7]},
                       'id-RSASSA-PSS': {'type': 'OBJECT IDENTIFIER',
                                         'value': ['pkcs-1', 10]},
                       'id-md2': {'type': 'OBJECT IDENTIFIER',
                                  'value': [('iso', 1),
                                            ('member-body', 2),
                                            ('us', 840),
                                            ('rsadsi', 113549),
                                            ('digestAlgorithm', 2),
                                            2]},
                       'id-md5': {'type': 'OBJECT IDENTIFIER',
                                  'value': [('iso', 1),
                                            ('member-body', 2),
                                            ('us', 840),
                                            ('rsadsi', 113549),
                                            ('digestAlgorithm', 2),
                                            5]},
                       'id-mgf1': {'type': 'OBJECT IDENTIFIER',
                                   'value': ['pkcs-1', 8]},
                       'id-pSpecified': {'type': 'OBJECT IDENTIFIER',
                                         'value': ['pkcs-1', 9]},
                       'id-sha1': {'type': 'OBJECT IDENTIFIER',
                                   'value': [('iso', 1),
                                             ('identified-organization', 3),
                                             ('oiw', 14),
                                             ('secsig', 3),
                                             ('algorithms', 2),
                                             26]},
                       'md2WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                'value': ['pkcs-1', 2]},
                       'md5WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                'value': ['pkcs-1', 4]},
                       'mgf1SHA1': {'type': 'MaskGenAlgorithm', 'value': '{'},
                       'pSpecifiedEmpty': {'type': 'PSourceAlgorithm',
                                           'value': '{'},
                       'pkcs-1': {'type': 'OBJECT IDENTIFIER',
                                  'value': [('iso', 1),
                                            ('member-body', 2),
                                            ('us', 840),
                                            ('rsadsi', 113549),
                                            ('pkcs', 1),
                                            1]},
                       'rSAES-OAEP-Default-Identifier': {'type': 'RSAES-AlgorithmIdentifier',
                                                         'value': '{'},
                       'rSASSA-PSS-Default-Identifier': {'type': 'RSASSA-AlgorithmIdentifier',
                                                         'value': '{'},
                       'rsaEncryption': {'type': 'OBJECT IDENTIFIER',
                                         'value': ['pkcs-1', 1]},
                       'sha1': {'type': 'HashAlgorithm', 'value': '{'},
                       'sha1WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                 'value': ['pkcs-1', 5]},
                       'sha256WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                   'value': ['pkcs-1', 11]},
                       'sha384WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                   'value': ['pkcs-1', 12]},
                       'sha512WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                   'value': ['pkcs-1', 13]}}}}

==> asn1tools_0.166.0.orig.tar.gz: asn1tools-0.166.0/tests/files/ietf/rfc3447.py <==
EXPECTED = {'PKCS-1': {'extensibility-implied': False,
            'imports': {'NIST-SHA2': ['id-sha256', 'id-sha384', 'id-sha512']},
            'object-classes': {'ALGORITHM-IDENTIFIER': {'members': [{'name': '&id',
                                                                     'type': 'OBJECT '
                                                                             'IDENTIFIER'},
                                                                    {'name': '&Type',
                                                                     'type': 'OpenType'}]}},
            'object-sets': {'OAEP-PSSDigestAlgorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                         'members': []},
                            'PKCS1-v1-5DigestAlgorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                           'members': []},
                            'PKCS1Algorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                'members': []},
                            'PKCS1MGFAlgorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                   'members': []},
                            'PKCS1PSourceAlgorithms': {'class': 'ALGORITHM-IDENTIFIER',
                                                       'members': []}},
            'tags': 'EXPLICIT',
            'types': {'AlgorithmIdentifier': {'members': [{'name': 'algorithm',
                                                           'table': {'type': 'InfoObjectSet'},
                                                           'type': 'ALGORITHM-IDENTIFIER.&id'},
                                                          {'name': 'parameters',
                                                           'optional': True,
                                                           'table': ['InfoObjectSet',
                                                                     ['.algorithm']],
                                                           'type': 'ALGORITHM-IDENTIFIER.&Type'}],
                                              'parameters': ['InfoObjectSet'],
                                              'type': 'SEQUENCE'},
                      'DigestAlgorithm': {'actual-parameters': ['{'],
                                          'type': 'AlgorithmIdentifier'},
                      'DigestInfo': {'members': [{'name': 'digestAlgorithm',
                                                  'type': 'DigestAlgorithm'},
                                                 {'name': 'digest',
                                                  'type': 'OCTET STRING'}],
                                     'type': 'SEQUENCE'},
                      'EncodingParameters': {'size': [(0, 'MAX')],
                                             'type': 'OCTET STRING'},
                      'HashAlgorithm': {'actual-parameters': ['{'],
                                        'type': 'AlgorithmIdentifier'},
                      'MaskGenAlgorithm': {'actual-parameters': ['{'],
                                           'type': 'AlgorithmIdentifier'},
                      'OtherPrimeInfo': {'members': [{'name': 'prime',
                                                      'type': 'INTEGER'},
                                                     {'name': 'exponent',
                                                      'type': 'INTEGER'},
                                                     {'name': 'coefficient',
                                                      'type': 'INTEGER'}],
                                         'type': 'SEQUENCE'},
                      'OtherPrimeInfos': {'element': {'type': 'OtherPrimeInfo'},
                                          'size': [(1, 'MAX')],
                                          'type': 'SEQUENCE OF'},
                      'PSourceAlgorithm': {'actual-parameters': ['{'],
                                           'type': 'AlgorithmIdentifier'},
                      'RSAES-AlgorithmIdentifier': {'actual-parameters': ['{'],
                                                    'type': 'AlgorithmIdentifier'},
                      'RSAES-OAEP-params': {'members': [{'default': 'sha1',
                                                         'name': 'hashAlgorithm',
                                                         'tag': {'number': 0},
                                                         'type': 'HashAlgorithm'},
                                                        {'default': 'mgf1SHA1',
                                                         'name': 'maskGenAlgorithm',
                                                         'tag': {'number': 1},
                                                         'type': 'MaskGenAlgorithm'},
                                                        {'default': 'pSpecifiedEmpty',
                                                         'name': 'pSourceAlgorithm',
                                                         'tag': {'number': 2},
                                                         'type': 'PSourceAlgorithm'}],
                                            'type': 'SEQUENCE'},
                      'RSAPrivateKey': {'members': [{'name': 'version',
                                                     'type': 'Version'},
                                                    {'name': 'modulus',
                                                     'type': 'INTEGER'},
                                                    {'name': 'publicExponent',
                                                     'type': 'INTEGER'},
                                                    {'name': 'privateExponent',
                                                     'type': 'INTEGER'},
                                                    {'name': 'prime1',
                                                     'type': 'INTEGER'},
                                                    {'name': 'prime2',
                                                     'type': 'INTEGER'},
                                                    {'name': 'exponent1',
                                                     'type': 'INTEGER'},
                                                    {'name': 'exponent2',
                                                     'type': 'INTEGER'},
                                                    {'name': 'coefficient',
                                                     'type': 'INTEGER'},
                                                    {'name': 'otherPrimeInfos',
                                                     'optional': True,
                                                     'type': 'OtherPrimeInfos'}],
                                        'type': 'SEQUENCE'},
                      'RSAPublicKey': {'members': [{'name': 'modulus',
                                                    'type': 'INTEGER'},
                                                   {'name': 'publicExponent',
                                                    'type': 'INTEGER'}],
                                       'type': 'SEQUENCE'},
                      'RSASSA-AlgorithmIdentifier': {'actual-parameters': ['{'],
                                                     'type': 'AlgorithmIdentifier'},
                      'RSASSA-PSS-params': {'members': [{'default': 'sha1',
                                                         'name': 'hashAlgorithm',
                                                         'tag': {'number': 0},
                                                         'type': 'HashAlgorithm'},
                                                        {'default': 'mgf1SHA1',
                                                         'name': 'maskGenAlgorithm',
                                                         'tag': {'number': 1},
                                                         'type': 'MaskGenAlgorithm'},
                                                        {'default': 20,
                                                         'name': 'saltLength',
                                                         'tag': {'number': 2},
                                                         'type': 'INTEGER'},
                                                        {'default': 'trailerFieldBC',
                                                         'name': 'trailerField',
                                                         'tag': {'number': 3},
                                                         'type': 'TrailerField'}],
                                            'type': 'SEQUENCE'},
                      'SHA1Parameters': {'type': 'NULL'},
                      'TrailerField': {'named-numbers': {'trailerFieldBC': 1},
                                       'type': 'INTEGER'},
                      'Version': {'named-numbers': {'multi': 1, 'two-prime': 0},
                                  'type': 'INTEGER'}},
            'values': {'emptyString': {'type': 'EncodingParameters',
                                       'value': '0x'},
                       'id-RSAES-OAEP': {'type': 'OBJECT IDENTIFIER',
                                         'value': ['pkcs-1', 7]},
                       'id-RSASSA-PSS': {'type': 'OBJECT IDENTIFIER',
                                         'value': ['pkcs-1', 10]},
                       'id-md2': {'type': 'OBJECT IDENTIFIER',
                                  'value': [('iso', 1),
                                            ('member-body', 2),
                                            ('us', 840),
                                            ('rsadsi', 113549),
                                            ('digestAlgorithm', 2),
                                            2]},
                       'id-md5': {'type': 'OBJECT IDENTIFIER',
                                  'value': [('iso', 1),
                                            ('member-body', 2),
                                            ('us', 840),
                                            ('rsadsi', 113549),
                                            ('digestAlgorithm', 2),
                                            5]},
                       'id-mgf1': {'type': 'OBJECT IDENTIFIER',
                                   'value': ['pkcs-1', 8]},
                       'id-pSpecified': {'type': 'OBJECT IDENTIFIER',
                                         'value': ['pkcs-1', 9]},
                       'id-sha1': {'type': 'OBJECT IDENTIFIER',
                                   'value': [('iso', 1),
                                             ('identified-organization', 3),
                                             ('oiw', 14),
                                             ('secsig', 3),
                                             ('algorithms', 2),
                                             26]},
                       'md2WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                'value': ['pkcs-1', 2]},
                       'md5WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                'value': ['pkcs-1', 4]},
                       'mgf1SHA1': {'type': 'MaskGenAlgorithm', 'value': '{'},
                       'pSpecifiedEmpty': {'type': 'PSourceAlgorithm',
                                           'value': '{'},
                       'pkcs-1': {'type': 'OBJECT IDENTIFIER',
                                  'value': [('iso', 1),
                                            ('member-body', 2),
                                            ('us', 840),
                                            ('rsadsi', 113549),
                                            ('pkcs', 1),
                                            1]},
                       'rSAES-OAEP-Default-Identifier': {'type': 'RSAES-AlgorithmIdentifier',
                                                         'value': '{'},
                       'rSASSA-PSS-Default-Identifier': {'type': 'RSASSA-AlgorithmIdentifier',
                                                         'value': '{'},
                       'rsaEncryption': {'type': 'OBJECT IDENTIFIER',
                                         'value': ['pkcs-1', 1]},
                       'sha1': {'type': 'HashAlgorithm', 'value': '{'},
                       'sha1WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                 'value': ['pkcs-1', 5]},
                       'sha256WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                   'value': ['pkcs-1', 11]},
                       'sha384WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                   'value': ['pkcs-1', 12]},
                       'sha512WithRSAEncryption': {'type': 'OBJECT IDENTIFIER',
                                                   'value': ['pkcs-1', 13]}}}}
